<template>
	<div class="section-main-container layout-padding">
		<div class="section-main-padding layout-padding-auto layout-padding-view">
			<div class="section-user-search mb15">
				<el-form :inline="true" :model="state.tableData.param" class="demo-form-inline" label-position="left"
					size="default" @submit.prevent>
					<el-form-item label="交易日期">
						<el-date-picker v-model="state.tableData.param.startDateEndArr" type="daterange" range-separator="-"
							start-placeholder="开始日期" end-placeholder="结束日期" format="YYYY-MM-DD" value-format="YYYY-MM-DD" />
					</el-form-item>
					<el-form-item>
						<el-button type="primary" @click="getTableData">查询</el-button>
						<el-button type="default" @click="resetgetTableData">重置</el-button>
					</el-form-item>
				</el-form>
			</div>
			<el-table :data="state.tableData.data" v-loading="state.tableData.loading" style="width: 100%">
				<el-table-column prop="tradeDate" label="交易时间" show-overflow-tooltip></el-table-column>
				<el-table-column prop="tradeFlowNo" label="交易流水号" show-overflow-tooltip></el-table-column>
				<el-table-column prop="flowNo" label="财务流水号" show-overflow-tooltip></el-table-column>
				<el-table-column prop="accountOutName" label="出账方" show-overflow-tooltip></el-table-column>
				<el-table-column prop="accountInName" label="入账方" show-overflow-tooltip></el-table-column>
				<el-table-column prop="amount" label="交易金额" show-overflow-tooltip></el-table-column>
				<!-- <el-table-column prop="balance" label="交易后余额" show-overflow-tooltip></el-table-column> -->
				<el-table-column prop="direction" label="资金流向" show-overflow-tooltip></el-table-column>
				<el-table-column prop="tradeType" label="交易类型" show-overflow-tooltip></el-table-column>
				<el-table-column prop="accountsDealDate" label="账务处理时间" show-overflow-tooltip></el-table-column>
				<el-table-column prop="memo" label="备注" show-overflow-tooltip></el-table-column>
			</el-table>
			<el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="mt15"
				:pager-count="5" :page-sizes="[10, 20, 30, 100, 200, 300, 1000]"
				v-model:current-page="state.tableData.param.pageNumber" background
				v-model:page-size="state.tableData.param.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="state.tableData.total">
			</el-pagination>
		</div>
		<ConfigDialog ref="configDialogRef" @refresh="getTableData()" />
	</div>
</template>

<script setup lang="ts" name="targetData">
import { defineAsyncComponent, reactive, onMounted, ref, inject } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import { ConfigApi } from '/@/api/api'
import { useRoute, useRouter, onBeforeRouteUpdate } from 'vue-router';
import { refreshBtnView } from '/@/components/refreshView'
// 引入组件
const ConfigDialog = defineAsyncComponent(() => import('./dialog.vue'));
// 定义变量内容
const route = useRoute()
const configDialogRef = ref();
const state = reactive({
	tableData: {
		data: [],
		total: 0,
		loading: false,
		param: {
			startDateEndArr: [] as string[],
			startDateEndArrRest: [] as string[],
			startDate: '',
			endDate: '',
			pageNumber: 1,
			pageSize: 10,
		},
	},
});
// 初始化表格数据
const getTableData = () => {
	state.tableData.loading = true;
	let obj = JSON.parse(JSON.stringify(state.tableData.param))
	if (obj.startDateEndArr.length) {
		obj.startDate = (obj.startDateEndArr)[0]
		obj.endDate = (obj.startDateEndArr)[1]
	}
	delete obj.startDateEndArr
	delete obj.startDateEndArrRest
	ConfigApi().tradedetailtaskApi(obj).then(response => {
		console.log('response查询', response)
		if (response.code == 200) {
			state.tableData.data = response.data.list
			state.tableData.total = response.data.total;
		}
	}).catch((e) => { })
	setTimeout(() => {
		state.tableData.loading = false;
	}, 500);
};
const resetgetTableData = () => {
	let obj = {
		pageNumber: 1,
		pageSize: 10,
		startDate: '',
		endDate: '',
		startDateEndArr: state.tableData.param.startDateEndArrRest,
		startDateEndArrRest: []
	}
	state.tableData.param = reactive(obj)
	getTableData()
};
// // 打开新增弹窗
// const onOpenAdd = (type: string) => {
// 	configDialogRef?.value.openDialog(type);
// };
// // 打开修改弹窗
// const onOpenEdit = (type: string, row: Object) => {
// 	console.log(row)
// 	configDialogRef?.value.openDialog(type, row);
// };
// 页码改变
const onHandleSizeChange = (val: number) => {
	state.tableData.param.pageSize = val;
	getTableData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
	state.tableData.param.pageNumber = val;
	getTableData();
};
//刷新当前列表
// const reload = inject('reload')//子接收
const refreshBtn = () => {
	refreshBtnView(route)
}
// 页面加载时
onMounted(() => {
	//获取近天的日期
	var tempDate = new Date() // 获取今天的日期
	let nowDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	tempDate.setDate(tempDate.getDate() - 6) // 今天的前N天的日期，N自定义
	var endDate = tempDate.getFullYear() + '-' + (tempDate.getMonth() + 1 < 10 ? '0' + (tempDate.getMonth() + 1) : tempDate.getMonth() + 1) + '-' + (tempDate.getDate() < 10 ? '0' + tempDate.getDate() : tempDate.getDate())
	console.log('endDate', endDate)

	state.tableData.param.startDateEndArr = ['' + endDate + '', '' + nowDate + '']//获取当前日期与前6天日期['2023-03-24','2023-03-30']
	state.tableData.param.startDateEndArrRest = ['' + endDate + '', '' + nowDate + '']//获取当前日期与前6天日期['2023-03-24','2023-03-30']
	getTableData();
});
</script>

<style scoped lang="scss">
.section-main-container {
	.section-main-padding {
		padding: 15px;

		.el-table {
			flex: 1;
		}

	}
}
</style>
